# jutsu
**jutsu** is a simple tool to independently verify the Bitcoin supply.

[![License](https://img.shields.io/badge/license-MIT-blue.svg?style=flat&logo=bitcoin&color=orange)](https://pypi.org/project/jutsu)

In order to use jutsu, you need a fully-synced Bitcoin full node with the rpc server enabled in `bitcoin.conf`.

[![jutsu](https://github.com/merwane/jutsu/raw/master/jutsu.png)](https://github.com/merwane/jutsu)

## Installation
---------------
```console
$ pip install jutsu
```

## Usage
---------------
```console
$ jutsu
```

## Notes
-------------
* jutsu is built with [oogway](https://oogway.6conf.com), a secure Bitcoin utility library for Python by [6conf](https://6conf.com).

## Support
-------------
Check out [6conf](https://6conf.com) to donate.